@@ -63,12 +63,12 @@ def create_many_sql(table_name: str, data_list: list, conversion=False, update=F
             sql += ')  values ('
             for key in data_keys:
                 value = data.get(key)
-                if isinstance(value, str) or conversion:
-                    sql += f'"%s",'
-                elif value == None:
-                    sql += f'null,'
+                # if isinstance(value, str) or conversion:
+                #     sql += f'"%s",'
+                if value == None:
+                    sql += '%s,'
                 else:
-                    sql += f'%s,'
+                    sql += '%s,'
             sql = sql.rstrip(',')
     if update:
         sql += ")  ON DUPLICATE KEY UPDATE "
@@ -82,7 +82,3 @@ def create_many_sql(table_name: str, data_list: list, conversion=False, update=F
         rel_data.append(tuple(item.values()))
     return sql, rel_data
 
-
-if __name__ == '__main__':
-    d1, d2 = create_many_sql("ssdsadadasd", [{'w': 'd1', 'ew': 'd2', 'wr': 'd3', 'wa': 4}], update=True)
-    print(d1, d2)
